==> tuia-advert-center-api-2.0.1-sources.jar: cn/com/duiba/tuia/core/api/dto/statistics/DwsAdvertTimesDayDto.java <==
package cn.com.duiba.tuia.core.api.dto.statistics;

import cn.com.duiba.tuia.core.api.dto.BaseDto;

import java.util.Date;

public class DwsAdvertTimesDayDto extends BaseDto {

    private static final long serialVersionUID = -7756101673780328197L;
    private Date    curDate;
    private Long    advertId;
    private Integer times;
    private Long    launchCount;
    private Long    exposureCount;
    private Long    clickCount;
    private Long    consumeTotal;
    private Long    efClickCount;
    private Long    clickUv;
    /** 访问pv */
    private Integer visitPv;
    /** 转化pv */
    private Integer effectPv;
    
    /**
     * visitPv.
     *
     * @return  the visitPv
     * @since   JDK 1.8
     */
    public Integer getVisitPv() {
        return visitPv;
    }

    /**
     * visitPv.
     *
     * @param   visitPv    the visitPv to set
     * @since   JDK 1.8
     */
    public void setVisitPv(Integer visitPv) {
        this.visitPv = visitPv;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Integer getTimes() {
        return times;
    }

    public void setTimes(Integer times) {
        this.times = times;
    }

    public Long getLaunchCount() {
        return launchCount;
    }

    public void setLaunchCount(Long launchCount) {
        this.launchCount = launchCount;
    }

    public Long getExposureCount() {
        return exposureCount;
    }

    public void setExposureCount(Long exposureCount) {
        this.exposureCount = exposureCount;
    }

    public Long getClickCount() {
        return clickCount;
    }

    public void setClickCount(Long clickCount) {
        this.clickCount = clickCount;
    }

    public Long getConsumeTotal() {
        return consumeTotal;
    }

    public void setConsumeTotal(Long consumeTotal) {
        this.consumeTotal = consumeTotal;
    }

    public Long getEfClickCount() {
        return efClickCount;
    }

    public void setEfClickCount(Long efClickCount) {
        this.efClickCount = efClickCount;
    }

    public Long getClickUv() {
        return clickUv;
    }

    public void setClickUv(Long clickUv) {
        this.clickUv = clickUv;
    }

    public Integer getEffectPv() {
        return effectPv;
    }

    public void setEffectPv(Integer effectPv) {
        this.effectPv = effectPv;
    }
}

==> tuia-advert-center-api-2.2.44-sources.jar: cn/com/duiba/tuia/core/api/dto/statistics/DwsAdvertTimesDayDto.java <==
package cn.com.duiba.tuia.core.api.dto.statistics;

import cn.com.duiba.tuia.core.api.dto.BaseDto;

import java.util.Date;

public class DwsAdvertTimesDayDto extends BaseDto {

    private static final long serialVersionUID = -7756101673780328197L;
    private Date    curDate;
    private Long    advertId;
    private Integer times;
    private Long    launchCount;
    private Long    exposureCount;
    private Long    clickCount;
    private Long    consumeTotal;
    private Long    efClickCount;
    private Long    clickUv;
    /** 访问pv */
    private Integer visitPv;
    /** 转化pv */
    private Integer effectPv;

    // 上级代理商id
    private Long agentId;

    public Long getAgentId() { return agentId; }

    public void setAgentId(Long agentId) { this.agentId = agentId; }
    
    /**
     * visitPv.
     *
     * @return  the visitPv
     * @since   JDK 1.8
     */
    public Integer getVisitPv() {
        return visitPv;
    }

    /**
     * visitPv.
     *
     * @param   visitPv    the visitPv to set
     * @since   JDK 1.8
     */
    public void setVisitPv(Integer visitPv) {
        this.visitPv = visitPv;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Integer getTimes() {
        return times;
    }

    public void setTimes(Integer times) {
        this.times = times;
    }

    public Long getLaunchCount() {
        return launchCount;
    }

    public void setLaunchCount(Long launchCount) {
        this.launchCount = launchCount;
    }

    public Long getExposureCount() {
        return exposureCount;
    }

    public void setExposureCount(Long exposureCount) {
        this.exposureCount = exposureCount;
    }

    public Long getClickCount() {
        return clickCount;
    }

    public void setClickCount(Long clickCount) {
        this.clickCount = clickCount;
    }

    public Long getConsumeTotal() {
        return consumeTotal;
    }

    public void setConsumeTotal(Long consumeTotal) {
        this.consumeTotal = consumeTotal;
    }

    public Long getEfClickCount() {
        return efClickCount;
    }

    public void setEfClickCount(Long efClickCount) {
        this.efClickCount = efClickCount;
    }

    public Long getClickUv() {
        return clickUv;
    }

    public void setClickUv(Long clickUv) {
        this.clickUv = clickUv;
    }

    public Integer getEffectPv() {
        return effectPv;
    }

    public void setEffectPv(Integer effectPv) {
        this.effectPv = effectPv;
    }
}
